from resource import ResourceInstance, ResourceCollection
from attendance import AttendanceCollection
from course_grade import CourseGradeCollection

class Section(ResourceInstance):
  subresources = [AttendanceCollection, CourseGradeCollection]


class SectionCollection(ResourceCollection):
  uri_resource_name = "section"
  collection_name = "sections"
  instance_class = Section
